@@ -11,9 +11,7 @@ ui <- fluidPage(  # Define UI for app that draws the bar chart
     selectInput(inputId = "myFill",
                 label = "fill",
                 choices = list(
-                  "colors", "darkred", "gray45", "gray75",
-                  "slategray3",
-                  "magenta3", "darkseagreen2", "purple",
+                  "colors",
                   "reds", "rusts", "yellows",
                   "olives", "greens", "emeralds", "turquoises",
                   "aquas", "blues", "purples", "violets",
